﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Infragistics.Documents.Excel;
using Infragistics.Controls.Grids;
using System.IO;
using Microsoft.Win32;
using RxVector.Common;
using RxVector.Data;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Messaging;
using GalaSoft.MvvmLight.Command;
using System.ComponentModel.Composition;
using Infragistics.Windows.DataPresenter;
using Infragistics.Persistence;
using Infragistics.Persistence.Primitives;

/*==========================================================================================================================================================================
	Modified Date		Modified By			Description
============================================================================================================================================================================
  12/13/2012          LMR                 Implemented error handling functionality
 *01/21/2013          Srinivasan A        Modified XamSchedulingQMenu_Opening For Program Assessment Visibility 
 *03/13/2013          Gunavathy           Changed Program-> Questionnaire in XamSchedulingQMenu_Opening
 *03/14/2013          Gunavathy           Changed ProgramCount to Questionnairecount
 *06/25/2013          Gunavathy           REmoved Gloalbs. Questionnairecount assignmnt in  XamSchedulingQMenu_Opening
 *07/26/2013          Srinivasan A        Added dgQResult_Loaded() event for filtering orders based on Patient Name
 *08/16/2013          M.Karthikeyan       change Cell double click event to mouse double click event
 *08/17/2013          M.Karthikeyan       Modify Mouse double click event to fix double click event
 * 08/23/2013         Gunavathy         Modification at MouseDoubleClick() for doubleclicking grid issue
 *11/16/2013          LMR                 Modification at dgQResult_Loaded() method     
 * 01/21/2014         Gunavathy           GetPatientPrograms - Included ShipmnetIDkey
 03/25/2014           Srinivasan A        Modification at dgQResult_MouseDoubleClick() for order not showing issue
****************************************************************************************************************************************************************************/
namespace RxVector.Views.Queues.PreOrder
{
    /// <summary>
    /// Interaction logic for Scheduling.xaml
    /// </summary>
    public partial class SchedulingQ : Window
    {
        public List<GetConfigurationValue_Result> VisibleSOC;
        RxVectorEntities ctx = new RxVectorEntities();
        public SchedulingQ()
        {
            InitializeComponent();
            
            this.Closing += new System.ComponentModel.CancelEventHandler(SchedulingQ_Closing);
            if (!ViewModelBase.IsInDesignModeStatic)
            {
                try
                {
                    DataContext = App.Container.GetExportedValue<ViewModelBase>(ViewModelTypes.SchedulingQViewModel);
                }
                catch (Exception ex)
                {
                    Errorlog.Writelog(ex, ViewTypes.SchedulingQueue, "PatientIDkey / " + Convert.ToString(Globals.PatientIDKey) + ",QueueName / " + Convert.ToString(Globals.QueueName));
                    MessageBox.Show(ex.Message.ToString(), Globals.AppName);
                }
            }
        }

        void SchedulingQ_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            SeralizeGridSettings(dgQResult);
        }
        public static PersistenceSettings GetStandardGridPersistenceSettings()
        {
            PersistenceSettings settings = new PersistenceSettings();
            settings.SavePersistenceOptions = PersistenceOption.OnlySpecified;

            // Filter menu
            PropertyNamePersistenceInfo prop = new PropertyNamePersistenceInfo();
            prop.PropertyName = "RowFiltersCollection";
            settings.PropertySettings.Add(prop);

            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "Columns[].Key";
            //settings.PropertySettings.Add(prop);

            //// Filter menu
            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "Columns[].FilterColumnSettings";
            //settings.PropertySettings.Add(prop);

            //// Maybe this is for top filter row?
            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "FilteringSettings";
            //settings.PropertySettings.Add(prop);

            //// Column sort

            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "SortingSettings";
            //settings.PropertySettings.Add(prop);

            //// Row grouping?
            //    //prop = new PropertyNamePersistenceInfo();
            //    //prop.PropertyName = "GroupBySettings";
            //    //settings.PropertySettings.Add(prop);

            //// Column order?
            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "ColumnMovingSettings";
            //settings.PropertySettings.Add(prop);

            //// Column width?
            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "ColumnResizingSettings";
            //settings.PropertySettings.Add(prop);

            //// Visible columns?
            //prop = new PropertyNamePersistenceInfo();
            //prop.PropertyName = "ColumnChooserSettings";
            //settings.PropertySettings.Add(prop);

            return settings;
        }

        public static void SeralizeGridSettings(XamGrid grid)
        {
            using (MemoryStream mStream = PersistenceManager.Save(grid, GetStandardGridPersistenceSettings()))
            {
                mStream.Position = 0;
                using (FileStream fs = new FileStream(@"E:\temp\persistence_scheduling.xml", FileMode.OpenOrCreate))
                {
                     mStream.WriteTo(fs);
                }
            }
        }

        public static void DeSeralizeGridSettings(XamGrid grid, string gridSettings)
        {
            if (!System.IO.File.Exists(@"E:\temp\persistence_scheduling.xml"))
                return;

            using (FileStream fs = File.OpenRead(@"E:\temp\persistence_scheduling.xml"))
            {
                PersistenceManager.Load(grid, fs, GetStandardGridPersistenceSettings());
            }

            using (MemoryStream ms = new MemoryStream(Encoding.ASCII.GetBytes(gridSettings)))
            {

                ms.Position = 0;

                PersistenceManager.Load(grid, ms, GetStandardGridPersistenceSettings());

            }

        }
        public SchedulingQ(Window parent)
            : this()
        {
            this.Owner = parent;
        }
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            VisibleSOC = new List<Data.GetConfigurationValue_Result>();
            VisibleSOC = ctx.GetConfigurationValue("EnabletoViewSOCinQueues").ToList();
            if (VisibleSOC != null && VisibleSOC.Count > 0 && Convert.ToString(VisibleSOC.ElementAt(0).ConfigValue).ToUpper() == "TRUE")
            {
                dgQResult.Columns["soc"].Visibility = Visibility.Visible;
            }
            else
            {
                dgQResult.Columns["soc"].Visibility = Visibility.Collapsed;

            }

            foreach (Column c in this.dgQResult.Columns.DataColumns)
                c.MinimumWidth = 30;
 
        }
        private void XamSchedulingQMenu_Opening(object sender, Infragistics.Controls.Menus.OpeningEventArgs e)
        {
            List<CellControl> cellRow = e.GetClickedElements<CellControl>();
            if (cellRow.Count == 0)
            {
                e.Cancel = true;
            }
            else
            {
                //this.dgQResult.ActiveCell = cellRow[0].Cell;
                Globals.PatientIDKey = Convert.ToInt64(cellRow[0].Cell.Row.Cells["PatientIDKey"].Value);
                Globals.OrderIDKey = Convert.ToInt64(cellRow[0].Cell.Row.Cells["OrderIDKey"].Value);
                Globals.OrderNumber = cellRow[0].Cell.Row.Cells["OrderNumber"].Value.ToString();
                Globals.ShipmentIDKey = Convert.ToInt64(cellRow[0].Cell.Row.Cells["ShipmentIDKey"].Value);
                if (cellRow[0].Cell.Row.Cells.Count > 26)
                {
                    Globals.QueueIDKey = Convert.ToInt64(cellRow[0].Cell.Row.Cells["QueueIDKey"].Value);
                    mnuSendFax.Visibility = Visibility.Collapsed;
                    mnuSendFaxParent.Visibility = Visibility.Visible;
                }
                if (cellRow[0].Cell.Row.Cells.Count == 26)
                {
                    mnuSendFax.Visibility = Visibility.Visible;
                    mnuSendFaxParent.Visibility = Visibility.Collapsed;
                    Globals.RxIDKey = Convert.ToInt64(cellRow[0].Cell.Row.Cells["RxIDKey"].Value);
                }

                // Patient Assessment menu Concept changes:                                                                                       -- Added by Vinoth( Jan-4-2013)
                // While patient order is created, Assessment is needed or not is decided and records is inserted in dmPatientProgram table
                // Based on the record count from the above table Assessement menu is shown:
                // When no record - Assessment menu is not shown
                // When record is there - Assessment is shown

                System.Data.Objects.ObjectParameter QuestionnaireCount = new System.Data.Objects.ObjectParameter("QuestionnaireCount", typeof(global::System.Int32));
                System.Data.Objects.ObjectParameter QuestionnaireIdkey = new System.Data.Objects.ObjectParameter("QuestionnaireIDkey", typeof(global::System.Int64));

                ctx.GetPatientPrograms(Globals.PatientIDKey, Globals.OrderIDKey,Globals.ShipmentIDKey, QuestionnaireCount, QuestionnaireIdkey);
                int Questionnairecount = Convert.ToInt32(QuestionnaireCount.Value);
               
                if (Questionnairecount > 0)
                {
                    Assessment.Visibility = Visibility.Visible;    // When Patient's Order need a mandatory Assessment 
                    //Globals.ProgramNeedsAssessment = true;
                    Globals.QuestionnaireId  = Convert.ToInt32(QuestionnaireIdkey.Value);
                }
                else if (Questionnairecount == 0)
                {
                    Assessment.Visibility = Visibility.Collapsed;  // When Patient's Order doesnt need a mandatory Assessment 
                }
                else
                {
                    Assessment.Visibility = Visibility.Collapsed;
                }
            }
        }

        private void btnExport_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (dgQResult.Rows.Count > 0)
                {
                    // dgQResult.Rows.Add();
                    Workbook wb = new Workbook();
                    //wb.SetCurrentFormat(WorkbookFormat.Excel2007);
                    // Add worksheet
                    Worksheet worksheet1 = wb.Worksheets.Add("Worksheet1");
                    WorksheetRow worksheetRow;
                    Column gridColumn;
                    WorksheetCell worksheetCell;
                   
                    foreach (Row gridRow in dgQResult.Rows)
                    {
                        worksheetRow = worksheet1.Rows[gridRow.Index + 1];
                        for (int columnIndex = 0; columnIndex < dgQResult.Columns.Count; columnIndex++)
                        {
                            gridColumn = dgQResult.Columns[columnIndex] as Column;
                            if (gridColumn != null)
                            {
                                if (gridColumn.Visibility == Visibility.Visible)
                                {
                                    worksheetRow.Cells[columnIndex].Value = gridRow.Cells[columnIndex].Value;
                                    if (gridRow.Index == 0)
                                    {
                                        //worksheetRow.Cells[columnIndex].Value = gridRow.Cells[columnIndex].Value;
                                        worksheetCell = worksheet1.Rows[0].Cells[columnIndex];
                                        worksheetCell.Value = gridColumn.HeaderText;
                                    }
                                }
                            }
                        }
                    }
                    SaveFileDialog savefileDialog = new SaveFileDialog { Filter = "Excel files|*.xls", DefaultExt = "xls" };
                    if (savefileDialog.ShowDialog() == true)
                    {
                        Stream stream = savefileDialog.OpenFile();
                        wb.Save(stream);
                        stream.Close();
                        MessageBox.Show("Your Excel has been Exported.", "Export Complete", MessageBoxButton.OK);
                    }

                    //worksheet1.PrintOptions.PaperSize = PaperSize.A4;
                    worksheet1.PrintOptions.ScalingType = ScalingType.FitToPages;
                    CustomView alternateView = wb.CustomViews.Add("Alternate Settings", true, true);
                    PrintOptions alternatePrintOptions = alternateView.GetPrintOptions(worksheet1);
                    alternatePrintOptions.Orientation = Infragistics.Documents.Excel.Orientation.Landscape;
                    alternatePrintOptions.PrintErrors = PrintErrors.PrintAsDashes;
                    alternateView.Apply();
                }
                else
                    MessageBox.Show("No Records to export");
            }
            catch (Exception ex)
            {
                Errorlog.Writelog(ex, ViewTypes.SchedulingQueue, "PatientIDkey / " + Convert.ToString(Globals.PatientIDKey) + ",QueueName / " + Convert.ToString(Globals.QueueName));
                MessageBox.Show(ex.Message.ToString(), Globals.AppName);
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Controls.ExportHelper.Print(dgQResult);
        }

        private void dgQResult_MouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            if (dgQResult.Rows.Count > 0)
            {

                var sourceParent = VisualTreeHelper.GetParent((DependencyObject)e.OriginalSource);
                FrameworkElement fwe = VisualTreeHelper.GetParent(sourceParent) as FrameworkElement;
                if (fwe.DataContext is GetOrderItemsQueueResult)
                {
                    GetOrderItemsQueueResult active = (GetOrderItemsQueueResult)fwe.DataContext;
                    Globals.PatientIDKey = Convert.ToInt64(active.PatientIDKey);
                    Globals.ShipmentIDKey = Convert.ToInt64(active.ShipmentIDKey);
                    Globals.OrderIDKey = Convert.ToInt64(active.OrderIDKey);
                    Globals.OrderNumber = Convert.ToString(active.OrderNumber);
                }
                else if (fwe.DataContext is GetQueueResult)
                {
                    GetQueueResult active = (GetQueueResult)fwe.DataContext;
                    Globals.PatientIDKey = Convert.ToInt64(active.PatientIDKey);
                    Globals.OrderIDKey = Convert.ToInt64(active.OrderIDKey);
                    Globals.OrderNumber = active.OrderNumber;
                    Globals.ShipmentIDKey = Convert.ToInt64(active.ShipmentIDKey);
                }

               
            }
        }

        private void dgQResult_Loaded(object sender, RoutedEventArgs e)
        {
            DeSeralizeGridSettings(dgQResult, Globals.persistence_schedulingq);

            //Added on 11/16/2013 by LMR *******************************************************************************
           List<GetConfigurationValue_Result> listHealthSystemGroup = new List<GetConfigurationValue_Result>();
            listHealthSystemGroup = ctx.GetConfigurationValue("VisibleHealthSystemGroupInQueue").ToList();
            if (listHealthSystemGroup != null && listHealthSystemGroup.Count > 0 && Convert.ToString(listHealthSystemGroup.ElementAt(0).ConfigValue).ToUpper() == "TRUE")
            {
                dgQResult.Columns["HealthSystemGroup"].Visibility = Visibility.Visible;
            }
            else
                dgQResult.Columns["HealthSystemGroup"].Visibility = Visibility.Collapsed;
            //**********************************************************************************************************
            if (Globals.FromQueue == ViewTypes.SchedulingQ)
            {
                /* To Filter by passing OrderNumber*/
                //object OrderNumber = Globals.OrderNumber;
                //if (Globals.OrderNumber != null && Globals.OrderNumber != "")
                //{
                //    Column col = dgQResult.Columns.DataColumns["OrderNumber"];
                //    RowsFilter rf = new RowsFilter(typeof(string), col);
                //    Infragistics.ComparisonCondition compCond = new Infragistics.ComparisonCondition();
                //    compCond.Operator = Infragistics.ComparisonOperator.Equals;
                //    compCond.FilterValue = OrderNumber;
                //    rf.Conditions.Add(compCond);
                //    dgQResult.FilteringSettings.RowFiltersCollection.Add(rf);
                //} 

                /* To Filter by passing PatientName*/
                if (Globals.PatientName != null && Globals.PatientName != "")
                {
                    object PatientName = Globals.PatientName;
                    Column col = dgQResult.Columns.DataColumns["PatientName"];
                    RowsFilter rf = new RowsFilter(typeof(string), col);
                    Infragistics.ComparisonCondition compCond = new Infragistics.ComparisonCondition();
                    compCond.Operator = Infragistics.ComparisonOperator.Contains;
                    compCond.FilterValue = PatientName;
                    rf.Conditions.Add(compCond);
                    dgQResult.FilteringSettings.RowFiltersCollection.Add(rf);
                }
            }
        }

        private void XamMenuItem_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                object QueueFaxMenuItemID = (sender as FrameworkElement).Tag;
                if (Convert.ToInt64(QueueFaxMenuItemID) > 0)
                {
                    Globals.QueueFaxMenuItemIDKey = Convert.ToInt64(QueueFaxMenuItemID);
                    AppMessages.ShowPopUpWindow.Send(ViewTypes.FaxConfirmation);
                }
            }
            catch (Exception ex)
            {
                Errorlog.Writelog(ex, ViewTypes.SchedulingQ, "PatientIDkey / " + Convert.ToString(Globals.PatientIDKey) + ",QueueName / " + Convert.ToString(Globals.QueueName));
                MessageBox.Show(ex.Message.ToString(), Globals.AppName);
            }

        }

        private void XamMenuItem_Click1(object sender, RoutedEventArgs e)
        {
            try
            {
                object QueueFaxMenuItemID = (sender as FrameworkElement).Tag;
                if (Convert.ToInt64(QueueFaxMenuItemID) > 0)
                {
                    Globals.QueueFaxMenuItemIDKey = Convert.ToInt64(QueueFaxMenuItemID);
                    AppMessages.ShowPopUpWindow.Send(ViewTypes.FaxConfirmation);
                }
            }
            catch (Exception ex)
            {
                Errorlog.Writelog(ex, ViewTypes.SchedulingQ, "PatientIDkey / " + Convert.ToString(Globals.PatientIDKey) + ",QueueName / " + Convert.ToString(Globals.QueueName));
                MessageBox.Show(ex.Message.ToString(), Globals.AppName);
            }

        }
    }
}


